==> ejc-credentials-impl-3.0.0-20220609.021040-45-sources.jar: com/ejianc/certify/vo/AccountBaseVO.java <==
package com.ejianc.certify.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 基本补贴表
 * 
 * @author generator
 * 
 */
public class AccountBaseVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private String pkPsndoc; // 人员主键
    private String psncode; // 人员编码
    private Long pkCertifreg; // 证件
    private Long pkCertiftype; // 证件类别
    private String djmonth; // 登记日期
    private String expireTime; // 证件失效时间
    private String bttype; // 补贴类别（1-一次性奖励额 2-基本补贴额）
    private String lastjfdate; // 最后计费月份(基本补贴额，初次登记该字段=登记日期)
    private String isstop; // 是否停止计费
    private String stopTime; // 停止计费时间
    private String vmemo; // 备注
    private Date ts; // 时间戳
    

    public String getPkPsndoc() {
        return pkPsndoc;
    }

    public void setPkPsndoc(String pkPsndoc) {
        this.pkPsndoc = pkPsndoc;
    }
    public String getPsncode() {
        return psncode;
    }

    public void setPsncode(String psncode) {
        this.psncode = psncode;
    }
    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public String getDjmonth() {
        return djmonth;
    }

    public void setDjmonth(String djmonth) {
        this.djmonth = djmonth;
    }
    public String getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(String expireTime) {
        this.expireTime = expireTime;
    }
    public String getBttype() {
        return bttype;
    }

    public void setBttype(String bttype) {
        this.bttype = bttype;
    }
    public String getLastjfdate() {
        return lastjfdate;
    }

    public void setLastjfdate(String lastjfdate) {
        this.lastjfdate = lastjfdate;
    }
    public String getIsstop() {
        return isstop;
    }

    public void setIsstop(String isstop) {
        this.isstop = isstop;
    }
    public String getStopTime() {
        return stopTime;
    }

    public void setStopTime(String stopTime) {
        this.stopTime = stopTime;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    
}

==> ejc-credentials-impl-3.0.0-20220616.071707-59-sources.jar: com/ejianc/certify/vo/AccountBaseVO.java <==
package com.ejianc.certify.vo;

import com.ejianc.framework.skeleton.template.BaseVO;

import java.util.Date;


/**
 * 基本补贴表
 * 
 * @author generator
 * 
 */
public class AccountBaseVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private Long pkPsndoc; // 人员主键
    private String psncode; // 人员编码
    private Long pkCertifreg; // 证件
    private Long pkCertiftype; // 证件类别
    private String djmonth; // 登记日期
    private String expireTime; // 证件失效时间
    private String bttype; // 补贴类别（1-一次性奖励额 2-基本补贴额）
    private String lastjfdate; // 最后计费月份(基本补贴额，初次登记该字段=登记日期)
    private String isstop; // 是否停止计费
    private String stopTime; // 停止计费时间
    private String vmemo; // 备注
    private Date ts; // 时间戳
    

    public Long getPkPsndoc() {
        return pkPsndoc;
    }

    public void setPkPsndoc(Long pkPsndoc) {
        this.pkPsndoc = pkPsndoc;
    }
    public String getPsncode() {
        return psncode;
    }

    public void setPsncode(String psncode) {
        this.psncode = psncode;
    }
    public Long getPkCertifreg() {
        return pkCertifreg;
    }

    public void setPkCertifreg(Long pkCertifreg) {
        this.pkCertifreg = pkCertifreg;
    }
    public Long getPkCertiftype() {
        return pkCertiftype;
    }

    public void setPkCertiftype(Long pkCertiftype) {
        this.pkCertiftype = pkCertiftype;
    }
    public String getDjmonth() {
        return djmonth;
    }

    public void setDjmonth(String djmonth) {
        this.djmonth = djmonth;
    }
    public String getExpireTime() {
        return expireTime;
    }

    public void setExpireTime(String expireTime) {
        this.expireTime = expireTime;
    }
    public String getBttype() {
        return bttype;
    }

    public void setBttype(String bttype) {
        this.bttype = bttype;
    }
    public String getLastjfdate() {
        return lastjfdate;
    }

    public void setLastjfdate(String lastjfdate) {
        this.lastjfdate = lastjfdate;
    }
    public String getIsstop() {
        return isstop;
    }

    public void setIsstop(String isstop) {
        this.isstop = isstop;
    }
    public String getStopTime() {
        return stopTime;
    }

    public void setStopTime(String stopTime) {
        this.stopTime = stopTime;
    }
    public String getVmemo() {
        return vmemo;
    }

    public void setVmemo(String vmemo) {
        this.vmemo = vmemo;
    }
    public Date getTs() {
        return ts;
    }

    public void setTs(Date ts) {
        this.ts = ts;
    }
    
}
